defmodule DecentralisedBookIndexWeb.BookLive.Show do
  use DecentralisedBookIndexWeb, :live_view

  @impl true
  def render(assigns) do
    ~H"""
    <.header>
      Book {@book.id}
      <:subtitle>This is a book record from your database.</:subtitle>

      <:actions>
        <.link patch={~p"/books/#{@book}/edit"}>
          <.edit_button>
            Edit
          </.edit_button>
        </.link>
      </:actions>
    </.header>

    <.list>
      <:item title="Id">{@book.id}</:item>

      <:item title="Title">{@book.title}</:item>

      <:item title="Description">{@book.description}</:item>

      <:item title="Published">{@book.published}</:item>

      <:item title="Language">{@book.language}</:item>

      <:item title="Format">{@book.format}</:item>

      <:item title="Page count">{@book.page_count}</:item>

      <:item title="Cover image url">{@book.cover_image_url}</:item>
    </.list>

    <.back navigate={~p"/books"}>Back to books</.back>
    """
  end

  @impl true
  def mount(_params, _session, socket) do
    {:ok, socket}
  end

  @impl true
  def handle_params(%{"id" => id}, _, socket) do
    {:noreply,
     socket
     |> assign(:page_title, page_title(socket.assigns.live_action))
     |> assign(
       :book,
       Ash.get!(DecentralisedBookIndex.Metadata.Book, id, actor: socket.assigns.current_user)
     )}
  end

  defp page_title(:show), do: "Show Book"
  defp page_title(:edit), do: "Edit Book"
end
